@@ -1,8 +1,11 @@
 # pylint: disable=invalid-name
 from typing import NamedTuple
+import re
 
 __all__ = ('__version__', 'version_info')
 
+__version__ = '0.0.3'
+
 
 class Version(NamedTuple):
     major: int
@@ -12,15 +15,12 @@ class Version(NamedTuple):
 
     @classmethod
     def from_str(cls, s: str) -> 'Version':
-        major, minor, rest = s.split('.')
-        rest_parts = rest.split('-')
-        if len(rest_parts) == 1:
-            # Just micro
-            micro = rest[0]
-            tag = None
-        else:
-            micro, tag = rest_parts
-        return cls(int(major), int(minor), int(micro), tag)
+        m = re.match(r'(0|[1-9]\d*)\.(0|[1-9]\d*)\.(0|[1-9]\d*)(?:-(\w*))?', s)
+        major = m.group(1)
+        minor = m.group(2)
+        micro = m.group(3)
+        tag = m.group(4)
+        return cls(major, minor, micro, tag=tag)
 
     def __str__(self) -> str:
         """The full version as X.Y.Z-tag"""
@@ -34,5 +34,4 @@ class Version(NamedTuple):
         return f'{self.major}.{self.minor}'
 
 
-__version__ = '0.0.2'
 version_info = Version.from_str(__version__)
